==> gorilla-notebook-0.4.2.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.events.notifications.js <==
goog.provide('pinkgorilla.events.notifications');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('re_frame.core');
goog.require('pinkgorilla.notifications');
re_frame.core.reg_event_fx.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),(function (p__40666,p__40667){
var map__40668 = p__40666;
var map__40668__$1 = (((((!((map__40668 == null))))?(((((map__40668.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__40668.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__40668):map__40668);
var db = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__40668__$1,new cljs.core.Keyword(null,"db","db",993250759));
var vec__40669 = p__40667;
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40669,(0),null);
var n = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40669,(1),null);
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"db","db",993250759),cljs.core.update.cljs$core$IFn$_invoke$arity$4(db,new cljs.core.Keyword(null,"notifications","notifications",1685638001),cljs.core.conj,n),new cljs.core.Keyword(null,"dispatch-later","dispatch-later",291951390),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"ms","ms",-1152709733),(5000),new cljs.core.Keyword(null,"dispatch","dispatch",1319337009),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-dismiss","notification-dismiss",29017550),new cljs.core.Keyword(null,"id","id",-1388402092).cljs$core$IFn$_invoke$arity$1(n)], null)], null)], null)], null);
}));
re_frame.core.reg_event_db.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"notification-dismiss","notification-dismiss",29017550),(function (db,p__40674){
var vec__40675 = p__40674;
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40675,(0),null);
var notification_id = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40675,(1),null);
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(db,new cljs.core.Keyword(null,"notifications","notifications",1685638001),(function (notis){
return cljs.core.filterv((function (p1__40673_SHARP_){
return cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2(notification_id,new cljs.core.Keyword(null,"id","id",-1388402092).cljs$core$IFn$_invoke$arity$1(p1__40673_SHARP_));
}),notis);
}));
}));
re_frame.core.reg_event_db.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"process-error-response","process-error-response",10419145),(function (db,p__40678){
var vec__40679 = p__40678;
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40679,(0),null);
var location = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40679,(1),null);
var response = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40679,(2),null);
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.events.notifications","/tmp/form-init4304146612373765484.clj",33,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ERROR RESPONSE: ",response], null);
}),null)),null,-863707932);

var G__40682_40683 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"warning","warning",-1685650671),[cljs.core.str.cljs$core$IFn$_invoke$arity$1(location)," Error: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"status-text","status-text",-1834235478).cljs$core$IFn$_invoke$arity$1(response))," (",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"status","status",-1997798413).cljs$core$IFn$_invoke$arity$1(response)),")"].join(''))], null);
(re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__40682_40683) : re_frame.core.dispatch.call(null,G__40682_40683));

return db;
}));

//# sourceMappingURL=pinkgorilla.events.notifications.js.map

==> gorilla-notebook-0.4.3.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.events.notifications.js <==
goog.provide('pinkgorilla.events.notifications');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('re_frame.core');
goog.require('pinkgorilla.notifications');
re_frame.core.reg_event_fx.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),(function (p__40666,p__40667){
var map__40668 = p__40666;
var map__40668__$1 = (((((!((map__40668 == null))))?(((((map__40668.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__40668.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__40668):map__40668);
var db = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__40668__$1,new cljs.core.Keyword(null,"db","db",993250759));
var vec__40669 = p__40667;
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40669,(0),null);
var n = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40669,(1),null);
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"db","db",993250759),cljs.core.update.cljs$core$IFn$_invoke$arity$4(db,new cljs.core.Keyword(null,"notifications","notifications",1685638001),cljs.core.conj,n),new cljs.core.Keyword(null,"dispatch-later","dispatch-later",291951390),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"ms","ms",-1152709733),(5000),new cljs.core.Keyword(null,"dispatch","dispatch",1319337009),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-dismiss","notification-dismiss",29017550),new cljs.core.Keyword(null,"id","id",-1388402092).cljs$core$IFn$_invoke$arity$1(n)], null)], null)], null)], null);
}));
re_frame.core.reg_event_db.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"notification-dismiss","notification-dismiss",29017550),(function (db,p__40674){
var vec__40675 = p__40674;
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40675,(0),null);
var notification_id = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40675,(1),null);
return cljs.core.update.cljs$core$IFn$_invoke$arity$3(db,new cljs.core.Keyword(null,"notifications","notifications",1685638001),(function (notis){
return cljs.core.filterv((function (p1__40673_SHARP_){
return cljs.core.not_EQ_.cljs$core$IFn$_invoke$arity$2(notification_id,new cljs.core.Keyword(null,"id","id",-1388402092).cljs$core$IFn$_invoke$arity$1(p1__40673_SHARP_));
}),notis);
}));
}));
re_frame.core.reg_event_db.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"process-error-response","process-error-response",10419145),(function (db,p__40678){
var vec__40679 = p__40678;
var _ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40679,(0),null);
var location = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40679,(1),null);
var response = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__40679,(2),null);
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.events.notifications","/tmp/form-init759419009955081863.clj",33,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, ["ERROR RESPONSE: ",response], null);
}),null)),null,203184463);

var G__40682_40683 = new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"notification-add","notification-add",-85956164),pinkgorilla.notifications.notification.cljs$core$IFn$_invoke$arity$2(new cljs.core.Keyword(null,"warning","warning",-1685650671),[cljs.core.str.cljs$core$IFn$_invoke$arity$1(location)," Error: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"status-text","status-text",-1834235478).cljs$core$IFn$_invoke$arity$1(response))," (",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"status","status",-1997798413).cljs$core$IFn$_invoke$arity$1(response)),")"].join(''))], null);
(re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1 ? re_frame.core.dispatch.cljs$core$IFn$_invoke$arity$1(G__40682_40683) : re_frame.core.dispatch.call(null,G__40682_40683));

return db;
}));

//# sourceMappingURL=pinkgorilla.events.notifications.js.map
